==> haskell-gnuidn-0.2.2-153-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gnuidn.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gnuidn
version:              0.2.2
visibility:           public
id:                   gnuidn-0.2.2-7D6M5VOwL1XCqQpur4oCpx
key:                  gnuidn-0.2.2-7D6M5VOwL1XCqQpur4oCpx
license:              GPL-3.0-only
maintainer:           jmillikin@gmail.com
author:               John Millikin
stability:            experimental
homepage:             https://john-millikin.com/software/haskell-gnuidn/
synopsis:             Bindings for GNU IDN
category:             Codec, Text
abi:                  63a2fd1fa0f4bbe918b063b725bbf50e
exposed:              True
exposed-modules:
    Data.Text.IDN.IDNA Data.Text.IDN.Punycode Data.Text.IDN.StringPrep

hidden-modules:       Data.Text.IDN.Internal
import-dirs:          /usr/lib/ghc-8.8.3/site-local/gnuidn-0.2.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/gnuidn-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/gnuidn-0.2.2
hs-libraries:         HSgnuidn-0.2.2-7D6M5VOwL1XCqQpur4oCpx
extra-libraries:      idn idn
depends:              base-4.13.0.0 bytestring-0.10.10.0 text-1.2.4.0
haddock-interfaces:   /usr/share/doc/haskell-gnuidn/html/gnuidn.haddock
haddock-html:         /usr/share/doc/haskell-gnuidn/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gnuidn-0.2.2-169-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gnuidn.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gnuidn
version:              0.2.2
visibility:           public
id:                   gnuidn-0.2.2-8ACF02HJI54EHlJwOytBu
key:                  gnuidn-0.2.2-8ACF02HJI54EHlJwOytBu
license:              GPL-3.0-only
maintainer:           jmillikin@gmail.com
author:               John Millikin
stability:            experimental
homepage:             https://john-millikin.com/software/haskell-gnuidn/
synopsis:             Bindings for GNU IDN
category:             Codec, Text
abi:                  a2760de4a27964df7d32aea46c1ad70e
exposed:              True
exposed-modules:
    Data.Text.IDN.IDNA Data.Text.IDN.Punycode Data.Text.IDN.StringPrep

hidden-modules:       Data.Text.IDN.Internal
import-dirs:          /usr/lib/ghc-8.10.1/site-local/gnuidn-0.2.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/gnuidn-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/gnuidn-0.2.2
hs-libraries:         HSgnuidn-0.2.2-8ACF02HJI54EHlJwOytBu
extra-libraries:      idn idn
depends:              base-4.14.0.0 bytestring-0.10.10.0 text-1.2.3.2
haddock-interfaces:   /usr/share/doc/haskell-gnuidn/html/gnuidn.haddock
haddock-html:         /usr/share/doc/haskell-gnuidn/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
